@@ -91,6 +91,10 @@ class Sentence(abcsent.Sentence):
         else:
             return named_entities
 
+    def lang(self) -> str:
+        """Returns the language of the sentence."""
+        return self.nlp.iso639
+
     def next_para_pos(self) -> int:
         """Returns the next token position in the paragraph."""
         self.para_pos += 1
