@@ -292,6 +292,9 @@ class Tokenizer(tokenization_abc.Tokenization):
         # list of paragraphs making up a document
         sent_list, para_list = list(), list()
 
+        # SIDE EFFECT: Sentence will increment token_id by one, so that it can start from token_id and not from token_id+1 .
+        token_id = token_id -1
+
         # tokenization of each doc
         for doc in tqdm(docs, desc='Tokenization in progress...', position=0, leave=True):
 
@@ -313,8 +316,7 @@ class Tokenizer(tokenization_abc.Tokenization):
 
             # tokenization of each sentence
             for sent in sent_tokenize(text, language=self.nlp.language):
-                # Sentence will increment token_id, so that it can start from 0.
-                sent = Sentence(sent_id, token_id - 1, sent, self.nlp, self.nlp.config, para_id,
+                sent = Sentence(sent_id, token_id, sent, self.nlp, self.nlp.config, para_id,
                                 doc_id, para_pos, doc_pos, metadata)
                 para_pos, doc_pos = sent.para_pos, sent.doc_pos
                 sent_list.append(sent)
