@@ -3,7 +3,6 @@ from tqdm import tqdm
 import numpy as np
 import matplotlib.pyplot as plt
 from collections import defaultdict
-from compling.analysis.sentiment.lexicon.lexicon import Lexicon
 from compling.analysis.sentiment.sentiment import SentimentLexiconBased
 from typing import *
 from wordcloud import WordCloud
@@ -104,7 +103,7 @@ class SentimentAnalyzer(SentimentLexiconBased):
         for record in tqdm(index, desc='SentimentAnalysis in progress...', leave=True, position=0):
 
             n_token = len(record[text_field].split())
-            if n_token == 1 and len(record[text_field]) < min_len or min_len > n_token:
+            if n_token == 1 and len(record[text_field]) < min_len or min_len > n_token and n_token > 1:
                 continue
 
             if lang is not None and lang != record['lang_'] or \
@@ -191,10 +190,15 @@ class SentimentAnalyzer(SentimentLexiconBased):
 
             key = " + ".join([record[g] for g in self.group_by_field]).replace('.', '\u002E')
 
+            if 'is_negated_' in record and record['is_negated_']:
+                token = 'NOT_'+record[text_field]
+            else:
+                token = record[text_field]
+
             if record['sentiment_']['pos'] > record['sentiment_']['neg']:
-                polarities[key]['pos'][record[text_field]] += 1
+                polarities[key]['pos'][token] += 1
             elif record['sentiment_']['neg'] > record['sentiment_']['pos']:
-                polarities[key]['neg'][record[text_field]] += 1
+                polarities[key]['neg'][token] += 1
 
         return polarities
 
