@@ -108,4 +108,8 @@ class Sentix(Lexicon):
                 else:
                     polarities[k] /= count[k]
 
-        return polarities
\ No newline at end of file
+        return polarities
+
+if __name__ == '__main__':
+    s = Sentix()
+    print(s.polarity('essere'))
\ No newline at end of file
